@@ -32,7 +32,7 @@ fn symbol<'a>() -> Arg<'a> {
         .short('s')
         .long("symbol")
         .value_name("BTC")
-        .about("Cryptocurrency symbol to download (ie. BTC, ETH, LTC)")
+        .help("Cryptocurrency symbol to download (ie. BTC, ETH, LTC)")
         .takes_value(true)
         .display_order(1)
         .default_value("BTC")
@@ -50,7 +50,7 @@ fn base_currency<'a>() -> Arg<'a> {
         .short('b')
         .long("base_currency")
         .value_name("USDT")
-        .about("Cryptocurrency base trading pair")
+        .help("Cryptocurrency base trading pair")
         .takes_value(true)
         .display_order(2)
         .default_value("USD")
@@ -68,7 +68,7 @@ fn interval<'a>() -> Arg<'a> {
         .short('i')
         .long("interval")
         .value_name("1m, 5, 15m, 30m, 1h, 3h, 6h, 12h, 1D, 7D, 14D, 1M")
-        .about("Interval that will be used to download the data")
+        .help("Interval that will be used to download the data")
         .takes_value(true)
         .display_order(3)
         .default_value("1D")
@@ -86,7 +86,7 @@ fn start_date<'a>() -> Arg<'a> {
         .short('d')
         .long("start_date")
         .value_name("YYYY-MM-DD")
-        .about("Date to start downloading the data (ie. YYYY-MM-DD)")
+        .help("Date to start downloading the data (ie. YYYY-MM-DD)")
         .takes_value(true)
         .display_order(4)
         .default_value("2020-11-01")
@@ -104,7 +104,7 @@ fn end_date<'a>() -> Arg<'a> {
         .short('e')
         .long("end_date")
         .value_name("YYYY-MM-DD")
-        .about("Date up to the data will be downloaded (ie. YYYY-MM-DD)")
+        .help("Date up to the data will be downloaded (ie. YYYY-MM-DD)")
         .takes_value(true)
         .display_order(5)
         .default_value("2021-01-01")
@@ -184,11 +184,11 @@ fn check_and_transform_dates(start_date: &str, end_date: &str) -> (i64, i64) {
     )
 }
 /// Reads the arguments from stdin.
-pub fn main() -> Result<(), Box<dyn Error>> {
+fn main() -> Result<(), &'static dyn Error> {
     verify_arguments_from_app_instance(
         App::new("crypto-candlesticks-rust")
             .author("Pedro Torres")
-            .version("0.1.0")
+            .version("0.1.2")
             .after_help(repo_info())
             .about(info())
             .arg(symbol())
@@ -209,7 +209,7 @@ fn verify_arguments_from_app_instance(app_instance: clap::ArgMatches) {
         app_instance.value_of("start_date"),
         app_instance.value_of("end_date"),
     ) {
-        check_values_exist_on_the_exchange(symbol, base_currency, interval);
+        check_values_exist_on_the_exchange(symbol, base_currency, interval, start_date, end_date);
         let (parsed_start_date, parsed_end_date): (i64, i64) =
             check_and_transform_dates(start_date, end_date);
         check_default_arguments(
@@ -238,10 +238,16 @@ fn verify_arguments_from_app_instance(app_instance: clap::ArgMatches) {
     };
 }
 
-fn check_values_exist_on_the_exchange(symbol: &str, base_currency: &str, interval: &str) {
+fn check_values_exist_on_the_exchange(
+    symbol: &str,
+    base_currency: &str,
+    interval: &str,
+    start_date: &str,
+    end_date: &str,
+) {
     let message: String = format!(
-        "\n Data could not be downloaded ❌, please make sure your inputs are correct.\n Symbol: {}\n, Base Currency: {}\n, Interval: {}\n",
-        &symbol, &base_currency, &interval,
+        "\n Data could not be downloaded ❌, please make sure your inputs are correct.\n Symbol: {}\n, Base Currency: {}\n, Interval: {}\n, Start_date: {}\n, End_date: {}",
+        &symbol, &base_currency, &interval, &start_date, &end_date,
 
     );
     if !check_symbol(symbol) || !check_base_currency(base_currency) || !check_interval(interval) {
@@ -274,16 +280,17 @@ fn check_default_arguments(
 }
 
 #[cfg(test)]
-mod tests {
+mod success_tests {
     use super::main as entry_point;
     use std::env;
+
     #[test]
     fn main_1m() {
         env::set_var("symbol", "btc");
         env::set_var("base_currency", "usd");
         env::set_var("interval", "1m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
 
@@ -293,7 +300,7 @@ mod tests {
         env::set_var("base_currency", "usd");
         env::set_var("interval", "5m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
 
@@ -303,19 +310,25 @@ mod tests {
         env::set_var("base_currency", "usd");
         env::set_var("interval", "15m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
 
     #[test]
     fn main_30m() {
-        env::set_var("symbol", "btc");
+        env::set_var("symbol", "xrp");
         env::set_var("base_currency", "usd");
         env::set_var("interval", "30m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
+}
+
+#[cfg(test)]
+mod fail_tests {
+    use super::main as entry_point;
+    use std::env;
 
     #[test]
     #[should_panic]
@@ -324,8 +337,8 @@ mod tests {
         env::set_var("base_currency", "usd");
         env::set_var("interval", "30m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
-        entry_point().unwrap_err();
+        env::set_var("end_date", "2021-01-07");
+        entry_point().unwrap();
     }
 
     #[test]
@@ -335,7 +348,7 @@ mod tests {
         env::set_var("base_currency", "USDR");
         env::set_var("interval", "30m");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
 
@@ -346,7 +359,7 @@ mod tests {
         env::set_var("base_currency", "usd");
         env::set_var("interval", "10D");
         env::set_var("start_date", "2021-01-01");
-        env::set_var("end_date", "2021-02-01");
+        env::set_var("end_date", "2021-01-07");
         entry_point().unwrap();
     }
 
